@@ -101,6 +101,9 @@ INVALIDPARAMETER_EMPTYPARAM = 'InvalidParameter.EmptyParam'
 # 非法参数错误。
 INVALIDPARAMETER_ILLEGALPARAMETERERROR = 'InvalidParameter.IllegalParameterError'
 
+# 实例安全组超过限制。
+INVALIDPARAMETER_INSTANCESGOVERLIMITERROR = 'InvalidParameter.InstanceSGOverLimitError'
+
 # 业务参数错误。
 INVALIDPARAMETER_INVALIDPARAMETER = 'InvalidParameter.InvalidParameter'
 
@@ -176,6 +179,9 @@ INVALIDPARAMETERVALUE_UNVPCIDNOTEXISTS = 'InvalidParameterValue.UnVpcIdNotExists
 # weekday输入无效数据。
 INVALIDPARAMETERVALUE_WEEKDAYSISINVALID = 'InvalidParameterValue.WeekDaysIsInvalid'
 
+# 超过配额限制。
+LIMITEXCEEDED = 'LimitExceeded'
+
 # 绑定超过上限。
 LIMITEXCEEDED_EXCEEDUPPERLIMIT = 'LimitExceeded.ExceedUpperLimit'
 
@@ -203,6 +209,9 @@ LIMITEXCEEDED_REPLICATIONGROUPLOCKED = 'LimitExceeded.ReplicationGroupLocked'
 # 实例被其它流程锁住。
 RESOURCEINUSE_INSTANCEBEENLOCKED = 'ResourceInUse.InstanceBeenLocked'
 
+# 资源不足。
+RESOURCEINSUFFICIENT = 'ResourceInsufficient'
+
 # uin 值为空。
 RESOURCENOTFOUND_ACCOUNTDOESNOTEXISTS = 'ResourceNotFound.AccountDoesNotExists'
 
